@@ -7,8 +7,8 @@
 
 #pragma once
 
+#include "kcmutils_version.h"
 #include <KCModule>
-
 #include <QVariant>
 
 #include "akregatorconfig.h"
@@ -20,7 +20,11 @@ class KCMAkregatorArchiveConfig : public KCModule
     Q_OBJECT
 
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KCMAkregatorArchiveConfig(QWidget *parent, const QVariantList &args);
+#else
+    explicit KCMAkregatorArchiveConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
 
     void setArchiveMode(int mode);
     int archiveMode() const;
