@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,8 +9,8 @@
 using namespace Akregator;
 UserFeedBackManager::UserFeedBackManager(QObject *parent)
     : QObject(parent)
+    , mUserFeedbackProvider(new AkregatorUserFeedbackProvider(this))
 {
-    mUserFeedbackProvider = new AkregatorUserFeedbackProvider(this);
 }
 
 UserFeedBackManager *UserFeedBackManager::self()
